@@ -4,16 +4,14 @@
 .getresidualsTransformSubsample <- function(o, y, maxpo, trans, type){
   
   # Dimensionality of response
-  d <- max(length(dim(y)), 1)
+  d <- dim(as.matrix(y))[2]
   
   # a) Transform simulated responses to residuals (unless type == "y")
   sim <- o$store$sim
   if( !is.null(sim) ){
-   
     if(d == 1){ 
-       sim <- llply(seq_len(nrow(sim)), function(ii) sim[ii, ])
+       sim <- llply(seq_len(ncol(sim)), function(ii) sim[ , ii])
     } 
-    
     if( type != "y" ){
       sim <- llply(sim, 
                     function(.yy){  
@@ -21,24 +19,20 @@
                       return( residuals(o, type = type) )
                     }) 
     }
+    if( !is.null(trans) ){ sim <- llply(sim, trans) }
+    if( !is.matrix(sim[[1]]) ){ sim <- llply(sim, as.matrix) }
   }
   
   # b) Apply optional transformation to observed and simulated y's
-  if( !is.null(trans) ){
-    y <- as.vector(trans( y ))
-    if( !is.null(sim) ) { sim <- llply(sim, trans) }
-  }
+  if( !is.null(trans) ){ y <- trans( y ) }
   
   # c) Sample if too many points (> maxpo) 
-  m <- length( as.vector(y) )
+  m <- nrow( as.matrix(y) )
   sub <- if(m > maxpo) { 
     sample( c(rep(TRUE, maxpo), rep(FALSE, m-maxpo)) )
   } else { 
     rep(TRUE, m) 
   }
   
-  if( !is.null(sim) ){ sim <- do.call("rbind", sim) }
-  
   return( list("sim" = sim, "y" = y, "sub" = sub) )
-  
 }
