@@ -28,7 +28,7 @@ l_ciBar <- function(level = 0.95, mul = NULL, ...){
 #' @noRd
 #'
 l_ciBar.PtermFactor <- l_ciBar.MultiPtermNumeric <- l_ciBar.MultiPtermFactor <- 
-                       l_ciBar.ALE1DFactor <- l_ciBar.singleIndexInner1D <- function(a){
+                       l_ciBar.ALE1DFactor <- l_ciBar.siFactor <- function(a){
   
   xtra <- a$xtra
   a$xtra <- NULL
