@@ -50,7 +50,7 @@
 #' @rdname gammV
 #' @export gammV
 #
-gammV <- function(formula, random, family = gaussian(), data = list(), method = "REML", aGam = list(), aViz = list(), keepGAMObj = FALSE){
+gammV <- function(formula, random = NULL, family = gaussian(), data = list(), method = "REML", aGam = list(), aViz = list(), keepGAMObj = FALSE){
 
   obj <- do.call("gamm", c(list("formula" = formula, "random" = random, "family" = family, "data" = quote(data), "method" = method), aGam))
 
