@@ -9,7 +9,7 @@
 #'             of regression coefficients from a Gaussian approximation to the posterior, and then we simulate
 #'             a vector of response using each parameter vector. If \code{FALSE}, then \code{nsim} vectors of 
 #'             responses are simulated using parameters fixed at the posterior mode. 
-#' @param newdata Optional new data frame used to perform the simulations. To be passed to \link{predict.gam} and, 
+#' @param newdata Optional new data frame used to perform the simulations. To be passed to \link[mgcv]{predict.gam} and, 
 #'                if \code{post == TRUE}, to \code{postSim}.
 #' @param ... extra arguments to be passed to \link{simulate.gam} (if \code{post==FALSE}) or
 #'            \link{postSim} (if \code{post==TRUE}). For instance, we could pass prior 
@@ -87,12 +87,12 @@ getViz <- function(o, nsim = 0, post = FALSE, newdata, ...){
   # NB: we do not allow to use trans() here, as it might lead to problems with check1D and check2D
   if( nsim > 0 ){ 
     if( post ){ # Posterior simulations OR ...
-      tryCatch(o$store$sim <- t(postSim(o, nsim = nsim, newdata = newdata, trans = NULL, savePar = FALSE, ...)), 
+      tryCatch(o$store$sim <- postSim(o, nsim = nsim, newdata = newdata, trans = NULL, savePar = FALSE, ...), 
                error = function(e){ 
                  message( paste("postSim() failed:", e$message) ) 
                })
     } else {    # ... parameters fixed at MAP 
-      tryCatch(o$store$sim <- t(simulate(o, nsim = nsim, newdata = newdata, trans = NULL, ...)), 
+      tryCatch(o$store$sim <- simulate(o, nsim = nsim, newdata = newdata, trans = NULL, ...), 
                error = function(e){ 
                  message( paste("simulate.gam() failed:", e$message) ) 
                })
