@@ -1,5 +1,5 @@
 
-.onLoad <- function(libname = find.package("grattan"), pkgname = "grattan"){
+.onLoad <- function(...){
   
   # CRAN Note avoidance
   if(getRversion() >= "2.15.1") 
@@ -11,6 +11,15 @@
         "qu", "p")
     )
   invisible()
+  
+}
+
+.onAttach <- function(...){
+  
+  if( packageVersion("qgam") < "1.3.0" ){
+    packageStartupMessage("qgam version < 1.3.0 installed, argument err will be set to 0.05 in qgamV and mqgamV calls. \n Update to qgam 1.3.0 for automatic err selection")
+  }
+  
 }
 
 # .onUnload <- function (libpath) {
